# USAGE: HomeDotenv.parse
class HomeDotenv
  # With a ~/.env
  #
  #   SECRET_KEY=so-secret-really
  #
  # HOME_ENV = HomeDotenv.parse
  # puts HOME_ENV[:SECRET_KEY]
  #
  def self.parse(filename = nil)
    parsed_from_file(filename).merge(parsed_from_env)
  end

  class << self
    private

    def parsed_from_env
      Hash[*ENV.map { |k, v| [k.to_sym, v]}.flatten]
    end

    def parsed_from_file(filename)
      Hash[*read_lines(filename).map { |l| parse_line(l) }.flatten]
    end

    def read_lines(filename = nil)
      filename ||= Dir.home + '/.env'
      lines = File.read(filename).split("\n")
      lines.reject!(&:empty?)
      lines.reject! { |l| l[0] == '#' }
      lines.reject! { |l| !l.include?('=') || l.split('=').first.to_s == '' }
      lines
    end

    def parse_line(line)
      key = line.split('=').first.to_sym
      value = line.split('=')[1..-1].join('=')
      [key, value]
    end
  end
end
